#ifndef SRC_REGISTRATION_MATCHING_PROJECT_COORDS_H_
#define SRC_REGISTRATION_MATCHING_PROJECT_COORDS_H_

#include <glib.h>

int convert_catalog_coords(GFile *fileA, SirilWorldCS *coord, GFile *out);

#endif /* SRC_REGISTRATION_MATCHING_PROJECT_COORDS_H_ */
